# Changelog

## [0.1.8](https://github.com/cyber-francis/slack_notification/compare/v0.1.7...v0.1.8) (2024-01-02)


### Bug Fixes

* updated readme ([fa8fb09](https://github.com/cyber-francis/slack_notification/commit/fa8fb090c03ed97773cf76c5431f932831ddf4ee))

## [0.1.7](https://github.com/cyber-francis/slack_notification/compare/v0.1.6...v0.1.7) (2024-01-02)


### Bug Fixes

* optional fields ([0ddb4a6](https://github.com/cyber-francis/slack_notification/commit/0ddb4a6d8849a789a1a500a98b97e4f677d14e50))
* optional fields ([3b5b9a2](https://github.com/cyber-francis/slack_notification/commit/3b5b9a2d3e7e7ab19747a3f3d17c1a946b2f37b0))
* optional fields ([8144f72](https://github.com/cyber-francis/slack_notification/commit/8144f722829bed58204b2338d1d3db66bc85f80c))

## [0.1.6](https://github.com/cyber-francis/slack_notification/compare/v0.1.5...v0.1.6) (2024-01-02)


### Bug Fixes

* optional fields ([e1aa64d](https://github.com/cyber-francis/slack_notification/commit/e1aa64dc80ef4c2acabcd037090705530ab70458))

## [0.1.5](https://github.com/cyber-francis/slack_notification/compare/v0.1.4...v0.1.5) (2024-01-02)


### Bug Fixes

* requirements.txt ([727873d](https://github.com/cyber-francis/slack_notification/commit/727873d1c7cd37e1a1355b664dca2c390243fca5))
* requirements.txt ([3153523](https://github.com/cyber-francis/slack_notification/commit/31535231b646fdf92dffa7595f490d171adb24e5))

## [0.1.4](https://github.com/cyber-francis/slack_notification/compare/v0.1.3...v0.1.4) (2024-01-02)


### Bug Fixes

* requirements.txt ([578e30b](https://github.com/cyber-francis/slack_notification/commit/578e30b0488c4688f579f1685d59d099fc9ac5dc))
* requirements.txt ([be53f59](https://github.com/cyber-francis/slack_notification/commit/be53f5962ee3d6dcc6ae5e55c4ebc254d10b8261))

## [0.1.3](https://github.com/cyber-francis/slack_notification/compare/v0.1.2...v0.1.3) (2024-01-02)


### Bug Fixes

* requirements.txt ([f8d3052](https://github.com/cyber-francis/slack_notification/commit/f8d3052eb4c38193dc032329551174e81f9a5fc0))

## [0.1.2](https://github.com/cyber-francis/slack_notification/compare/v0.1.1...v0.1.2) (2024-01-02)


### Bug Fixes

* requirements.txt ([8f9e219](https://github.com/cyber-francis/slack_notification/commit/8f9e219ce0045a363ab4689e8f530dbd208c06f6))

## [0.1.1](https://github.com/cyber-francis/slack_notification/compare/v0.1.0...v0.1.1) (2024-01-02)


### Bug Fixes

* requirements.txt ([9ff623e](https://github.com/cyber-francis/slack_notification/commit/9ff623ef19d363efe355b644bace4f14d45f86d9))

## 0.1.0 (2024-01-02)


### Bug Fixes

* initial commit ([ce4d4d5](https://github.com/cyber-francis/slack_notification/commit/ce4d4d51f31c07886209a43771c157d3da762045))
* initial commit ([7df9203](https://github.com/cyber-francis/slack_notification/commit/7df9203c557314e65c3a8c11b2617e55622ac8a9))
* initial commit ([a552a4d](https://github.com/cyber-francis/slack_notification/commit/a552a4d60a71cffc5a221c986ac95bdb5636ab92))
* testing hooks ([2897adc](https://github.com/cyber-francis/slack_notification/commit/2897adc2303d5f20a26a92a9cdf540c766247edc))
